from setuptools import setup

setup(name='kannanpackage',
      version='0.2',
      author = 'Abhijith',
      author_email = 'akgamer077@gmail.com',
      description='Gaussian distributions',
      packages=['kannanpackage'],
      zip_safe=False)
